'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var addons = _interopDefault(require('@storybook/addons'));
var clientApi = require('@storybook/client-api');
var types = require('./types.js');

/**
 * function returning the global options
 * parameters and decorators
 */
const getGlobalOptions = () => {
    const store = window &&
        window.__STORYBOOK_CLIENT_API__ &&
        window.__STORYBOOK_CLIENT_API__.store();
    //@ts-ignore
    return store._globalMetadata;
};
/**
 * function returning the current story id
 */
const getCurrentStoryId = () => {
    const store = window &&
        window.__STORYBOOK_CLIENT_API__ &&
        window.__STORYBOOK_CLIENT_API__.store();
    const selection = store.getSelection();
    //@ts-ignore
    return selection ? selection.storyId : undefined;
};
let globalStoryId = undefined;
const getGlobalStoryId = () => {
    if (globalStoryId === undefined) {
        globalStoryId = getCurrentStoryId() || '.';
    }
    return globalStoryId;
};
/**
 * React hook hook that tracks the changes to the current story and returns it's id
 * @returns a story id as a React hook, when the the current story changes, will call back
 */
const useStoryId = () => {
    const [storyId, setStoryId] = React.useState(getGlobalStoryId());
    const channel = React.useMemo(() => addons.getChannel(), []);
    React.useEffect(() => {
        const onStoryChange = ({ storyId: id }) => {
            if (id !== globalStoryId) {
                globalStoryId = id;
                setStoryId(id);
            }
        };
        channel.on(types.UPDATE_STORY_CONTEXT, onStoryChange);
        return () => {
            channel.off(types.UPDATE_STORY_CONTEXT, onStoryChange);
        };
    }, [channel]);
    return storyId;
};
/**
 * React hook hook that tracks the changes to the current story and returns the data
 * @returns a story id , document id, name and parameters
 */
const useCurrentData = () => {
    const storyId = useStoryId();
    const storyStore = window.__STORYBOOK_CLIENT_API__._storyStore;
    const data = storyStore.fromId(storyId);
    const { kind, name, parameters = {} } = data || {};
    return {
        storyId,
        docId: kind,
        name,
        parameters,
    };
};
/**
 * React hook - returns a context similar (but not identical) that can be used as an input attribute to `<DocsContainer />`
 */
const useContext = () => {
    const channel = addons.getChannel();
    const storyId = useStoryId();
    const clientApi$1 = window.__STORYBOOK_CLIENT_API__;
    const storyStore = clientApi$1._storyStore;
    const configApi = new clientApi.ConfigApi({
        storyStore,
        //@ts-ignore
        channel: addons.getChannel(),
    });
    const context = {
        configApi,
        storyStore,
        channel,
        clientApi: clientApi$1,
    };
    const data = storyStore.fromId(storyId);
    const { kind, name, parameters = {} } = data || {};
    return Object.assign(Object.assign(Object.assign({}, context), data), { selectedKind: kind, selectedStory: name, parameters,
        storyId });
};

exports.UPDATE_STORY_CONTEXT = types.UPDATE_STORY_CONTEXT;
exports.getCurrentStoryId = getCurrentStoryId;
exports.getGlobalOptions = getGlobalOptions;
exports.useContext = useContext;
exports.useCurrentData = useCurrentData;
exports.useStoryId = useStoryId;
